@@ -68,6 +68,7 @@ def rpm2py_format(queryformat):
     def fmt_repl(matchobj):
         fill = matchobj.groups()[0]
         key = matchobj.groups()[1]
+        key = key.lower()  # we allow both uppercase and lowercase variants
         if key not in ALLOWED_QUERY_TAGS:
             return brackets(matchobj.group())
         if fill:
@@ -76,7 +77,7 @@ def rpm2py_format(queryformat):
             else:
                 fill = '<' + fill
             fill = ':' + fill
-        return '{0.' + key.lower() + fill + "}"
+        return '{0.' + key + fill + "}"
 
     def brackets(txt):
         return txt.replace('{', '{{').replace('}', '}}')
@@ -326,6 +327,9 @@ class RepoQueryCommand(commands.Command):
         if self.opts.querychangelogs:
             demands.changelogs = True
 
+        if self.opts.queryfilelist or self.opts.file or dnf.util._is_file_pattern_present(self.opts.key):
+            self.base.conf.optional_metadata_types += ["filelists"]
+
     def build_format_fn(self, opts, pkg):
         if opts.querychangelogs:
             out = []
@@ -720,8 +724,7 @@ class PackageWrapper(object):
     def _get_timestamp(timestamp):
         if timestamp > 0:
             dt = datetime.datetime.utcfromtimestamp(timestamp)
-            # TRANSLATORS: This is the default time format for dnf repoquery.
-            return dt.strftime(_("%Y-%m-%d %H:%M"))
+            return dt.strftime("%Y-%m-%d %H:%M")
         else:
             return ''
 
